@@ -20,18 +20,18 @@
 #ifndef DOLPHINVIEWCONTAINER_H
 #define DOLPHINVIEWCONTAINER_H
 
-#include <KFileItem>
-#include <KCompletion>
-#include <KIO/Job>
+#include "config-dolphin.h"
+#include "views/dolphinview.h"
 
+#include <KCompletion>
+#include <KFileItem>
+#include <KIO/Job>
 #include <KUrlNavigator>
 
 #include <QElapsedTimer>
+#include <QPushButton>
 #include <QWidget>
 
-#include <views/dolphinview.h>
-#include <config-dolphin.h>
-
 #ifdef KF5Activities_FOUND
 namespace KActivities {
     class ResourceInstance;
@@ -70,7 +70,7 @@ public:
     };
 
     DolphinViewContainer(const QUrl& url, QWidget* parent);
-    virtual ~DolphinViewContainer();
+    ~DolphinViewContainer() override;
 
     /**
      * Returns the current active URL, where all actions are applied.
@@ -93,6 +93,8 @@ public:
     void setAutoGrabFocus(bool grab);
     bool autoGrabFocus() const;
 
+    QString currentSearchText() const;
+
     const DolphinStatusBar* statusBar() const;
     DolphinStatusBar* statusBar();
 
@@ -318,7 +320,9 @@ private:
 
 private:
     QVBoxLayout* m_topLayout;
+    QWidget* m_navigatorWidget;
     KUrlNavigator* m_urlNavigator;
+    QPushButton* m_emptyTrashButton;
     DolphinSearchBox* m_searchBox;
     KMessageWidget* m_messageWidget;
 
