@@ -24,18 +24,14 @@
 
 #include "kitemlistcontroller.h"
 #include "kitemlistview.h"
-#include "kitemmodelbase.h"
-
 #include "private/kitemlistsmoothscroller.h"
 
 #include <QApplication>
 #include <QGraphicsScene>
 #include <QGraphicsView>
 #include <QScrollBar>
-#include <QStyle>
 #include <QStyleOption>
 
-
 /**
  * Replaces the default viewport of KItemListContainer by a
  * non-scrollable viewport. The scrolling is done in an optimized
@@ -48,7 +44,7 @@ class KItemListContainerViewport : public QGraphicsView
 public:
     KItemListContainerViewport(QGraphicsScene* scene, QWidget* parent);
 protected:
-    void wheelEvent(QWheelEvent* event) Q_DECL_OVERRIDE;
+    void wheelEvent(QWheelEvent* event) override;
 };
 
 KItemListContainerViewport::KItemListContainerViewport(QGraphicsScene* scene, QWidget* parent) :
@@ -70,8 +66,8 @@ void KItemListContainerViewport::wheelEvent(QWheelEvent* event)
 KItemListContainer::KItemListContainer(KItemListController* controller, QWidget* parent) :
     QAbstractScrollArea(parent),
     m_controller(controller),
-    m_horizontalSmoothScroller(0),
-    m_verticalSmoothScroller(0)
+    m_horizontalSmoothScroller(nullptr),
+    m_verticalSmoothScroller(nullptr)
 {
     Q_ASSERT(controller);
     controller->setParent(this);
@@ -83,10 +79,10 @@ KItemListContainer::KItemListContainer(KItemListController* controller, QWidget*
     m_verticalSmoothScroller = new KItemListSmoothScroller(verticalScrollBar(), this);
 
     if (controller->model()) {
-        slotModelChanged(controller->model(), 0);
+        slotModelChanged(controller->model(), nullptr);
     }
     if (controller->view()) {
-        slotViewChanged(controller->view(), 0);
+        slotViewChanged(controller->view(), nullptr);
     }
 
     connect(controller, &KItemListController::modelChanged,
@@ -100,7 +96,7 @@ KItemListContainer::~KItemListContainer()
     // Don't rely on the QObject-order to delete the controller, otherwise
     // the QGraphicsScene might get deleted before the view.
     delete m_controller;
-    m_controller = 0;
+    m_controller = nullptr;
 }
 
 KItemListController* KItemListContainer::controller() const
@@ -216,8 +212,8 @@ void KItemListContainer::slotViewChanged(KItemListView* current, KItemListView*
         disconnect(previous, &KItemListView::maximumItemOffsetChanged,
                    this, &KItemListContainer::updateItemOffsetScrollBar);
         disconnect(previous, &KItemListView::scrollTo, this, &KItemListContainer::scrollTo);
-        m_horizontalSmoothScroller->setTargetObject(0);
-        m_verticalSmoothScroller->setTargetObject(0);
+        m_horizontalSmoothScroller->setTargetObject(nullptr);
+        m_verticalSmoothScroller->setTargetObject(nullptr);
     }
     if (current) {
         scene->addItem(current);
@@ -257,8 +253,8 @@ void KItemListContainer::updateScrollOffsetScrollBar()
         return;
     }
 
-    KItemListSmoothScroller* smoothScroller = 0;
-    QScrollBar* scrollOffsetScrollBar = 0;
+    KItemListSmoothScroller* smoothScroller = nullptr;
+    QScrollBar* scrollOffsetScrollBar = nullptr;
     int singleStep = 0;
     int pageStep = 0;
     int maximum = 0;
@@ -308,8 +304,8 @@ void KItemListContainer::updateItemOffsetScrollBar()
         return;
     }
 
-    KItemListSmoothScroller* smoothScroller = 0;
-    QScrollBar* itemOffsetScrollBar = 0;
+    KItemListSmoothScroller* smoothScroller = nullptr;
+    QScrollBar* itemOffsetScrollBar = nullptr;
     int singleStep = 0;
     int pageStep = 0;
     if (view->scrollOrientation() == Qt::Vertical) {
