@@ -18,14 +18,14 @@
  ***************************************************************************/
 
 #include "kitemlistsizehintresolver.h"
-
-#include <kitemviews/kitemlistview.h>
+#include "kitemviews/kitemlistview.h"
 
 KItemListSizeHintResolver::KItemListSizeHintResolver(const KItemListView* itemListView) :
     m_itemListView(itemListView),
     m_logicalHeightHintCache(),
     m_logicalWidthHint(0.0),
     m_logicalHeightHint(0.0),
+    m_minHeightHint(0.0),
     m_needsResolving(false)
 {
 }
@@ -40,6 +40,12 @@ QSizeF KItemListSizeHintResolver::maxSizeHint()
     return QSizeF(m_logicalWidthHint, m_logicalHeightHint);
 }
 
+QSizeF KItemListSizeHintResolver::minSizeHint()
+{
+    updateCache();
+    return QSizeF(m_logicalWidthHint, m_minHeightHint);
+}
+
 QSizeF KItemListSizeHintResolver::sizeHint(int index)
 {
     updateCache();
@@ -161,6 +167,7 @@ void KItemListSizeHintResolver::updateCache()
             m_logicalHeightHint = 0.0;
         } else {
             m_logicalHeightHint = *std::max_element(m_logicalHeightHintCache.begin(), m_logicalHeightHintCache.end());
+            m_minHeightHint = *std::min_element(m_logicalHeightHintCache.begin(), m_logicalHeightHintCache.end());
         }
         m_needsResolving = false;
     }
