@@ -115,14 +115,6 @@ private slots:
     void refreshMetaData();
 
 private:
-    /**
-     * Checks whether the an URL is repesented by a place. If yes,
-     * then the place icon and name are shown instead of a preview.
-     * @return True, if the URL represents exactly a place.
-     * @param url The url to check.
-     */
-    bool applyPlace(const QUrl& url);
-
     /**
      * Sets the text for the label \a m_nameLabel and assures that the
      * text is split in a way that it can be wrapped within the
