@@ -21,9 +21,10 @@
 #ifndef PLACESPANEL_H
 #define PLACESPANEL_H
 
-#include <QUrl>
+#include "panels/panel.h"
+
 #include <QMimeData>
-#include <panels/panel.h>
+#include <QUrl>
 
 class KItemListController;
 class PlacesItem;
@@ -31,6 +32,7 @@ class PlacesItemModel;
 class PlacesView;
 class QGraphicsSceneDragDropEvent;
 class KJob;
+class QMenu;
 /**
  * @brief Combines bookmarks and mounted devices as list.
  */
@@ -40,7 +42,7 @@ class PlacesPanel : public Panel
 
 public:
     explicit PlacesPanel(QWidget* parent);
-    virtual ~PlacesPanel();
+    ~PlacesPanel() override;
     void proceedWithTearDown();
 
 signals:
@@ -51,11 +53,11 @@ signals:
     void storageTearDownExternallyRequested(const QString& mountPath);
 
 protected:
-    virtual bool urlChanged() Q_DECL_OVERRIDE;
-    virtual void showEvent(QShowEvent* event) Q_DECL_OVERRIDE;
+    bool urlChanged() override;
+    void showEvent(QShowEvent* event) override;
 
 public slots:
-    virtual void readSettings() Q_DECL_OVERRIDE;
+    void readSettings() override;
 
 private slots:
     void slotItemActivated(int index);
@@ -66,11 +68,9 @@ private slots:
     void slotItemDropEventStorageSetupDone(int index, bool success);
     void slotAboveItemDropEvent(int index, QGraphicsSceneDragDropEvent* event);
     void slotUrlsDropped(const QUrl& dest, QDropEvent* event, QWidget* parent);
-    void slotTrashUpdated(KJob* job);
     void slotStorageSetupDone(int index, bool success);
 
 private:
-    void emptyTrash();
     void addEntry();
     void editEntry(int index);
 
@@ -82,6 +82,8 @@ private:
 
     void triggerItem(int index, Qt::MouseButton button);
 
+    QAction* buildGroupContextMenu(QMenu* menu, int index);
+
 private:
     KItemListController* m_controller;
     PlacesItemModel* m_model;
