@@ -19,21 +19,19 @@
 
 #include "kcmdolphinviewmodes.h"
 
+#include "settings/viewmodes/viewsettingstab.h"
+
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <KPluginLoader>
-#include <QIcon>
-
-#include <settings/viewmodes/viewsettingstab.h>
 
 #include <QDBusConnection>
 #include <QDBusMessage>
-#include <QPushButton>
-#include <QVBoxLayout>
+#include <QIcon>
 #include <QTabWidget>
+#include <QVBoxLayout>
 
 K_PLUGIN_FACTORY(KCMDolphinViewModesConfigFactory, registerPlugin<DolphinViewModesConfigModule>(QStringLiteral("dolphinviewmodes"));)
-K_EXPORT_PLUGIN(KCMDolphinViewModesConfigFactory("kcmdolphinviewmodes"))
 
 DolphinViewModesConfigModule::DolphinViewModesConfigModule(QWidget* parent, const QVariantList& args) :
     KCModule(parent),
@@ -67,7 +65,7 @@ DolphinViewModesConfigModule::DolphinViewModesConfigModule(QWidget* parent, cons
     m_tabs.append(compactTab);
     m_tabs.append(detailsTab);
 
-    topLayout->addWidget(tabWidget, 0, 0);
+    topLayout->addWidget(tabWidget, 0, nullptr);
 }
 
 DolphinViewModesConfigModule::~DolphinViewModesConfigModule()
